# Bellos Installer

Install Bellos Scripting Languages into your Operating System 


## Usage of Bellos Installer

- **To use this script, you would run it with sudo privileges and specify an action:**

- To install a specific version: sudo bellos_installer install --version <branch_name>
- To list available versions: sudo bellos_installer list
- To install the latest version: sudo bellos_installer latest
- To use the upload placeholder: sudo bellos_installer update


## Website PYPI
- https://pypi.org/project/bellos_installer

### Installation
- `$ pip install bellos_installer`

### Upgrade (if not upgraded)
- `$ pip install --upgrade bellos_installer`

```
Name: bellos_installer
Version: 0.1.0
Summary: Install Bellos Scripting Languages into your Operating System 
Home-page: github.com/Architecture-Mechanism/bellos_installer
Author: Ronaldson Bellande
Author-email: ronaldsonbellande@gmail.com
License: GNU General Public License v3.0
Requires: 
Required-by:
```

## License

BellandeOS Scripting Language Installer is distributed under the [GNU General Public License v3.0](https://www.gnu.org/licenses/gpl-3.0.en.html), see [LICENSE](https://github.com/Architecture-Mechanism/bellos_installer/blob/main/LICENSE) and [NOTICE](https://github.com/Architecture-Mechanism/bellos_installer/blob/main/LICENSE) for more information.
